@@ -7,8 +7,6 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Nøglen er udløbet  eller appen er ikke aktiveret! Genindlæs siden!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Intern server fejl! Tjek din data/nextcloud.log log-fil for yderligere information.",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Forespørgslen mislykkedes, Nextcloud er i øjeblikket i vedligeholdelse tilstand!",
-    "Can not add feed: Exists already" : "Kan ikke tilføje feed: Det eksisterer allerede",
-    "Articles without feed" : "Artikler uden feed",
     "News" : "Nyheder",
     "Use system cron for updates" : "Benyt system cron til opdateringer",
     "Purge interval" : "Oprydningsinterval",
