@@ -144,7 +144,7 @@ class ItemMapperV2 extends NewsMapperV2
      *
      * @return int|null Removed items
      *
-     * @throws \Doctrine\DBAL\Exception|\OCP\DB\Exception
+     * @throws \Doctrine\DBAL\Exception
      */
     public function deleteOverThreshold(int $threshold, bool $removeUnread = false): ?int
     {
@@ -167,7 +167,7 @@ class ItemMapperV2 extends NewsMapperV2
             ->from($this->tableName)
             ->where('feed_id = :feedId')
             ->andWhere('starred = false')
-            ->orderBy('updated_date', 'DESC');
+            ->orderBy('last_modified', 'DESC');
 
         if ($removeUnread === false) {
             $rangeQuery->andWhere('unread = false');
